class InstagramPhoto {
  private String thumbnailUrl;
  private String linkUrl;
  private PImage thumbnail;
  
  public InstagramPhoto(String thumbnailUrl, String linkUrl) {
    this.thumbnailUrl = thumbnailUrl;
    this.linkUrl = linkUrl;
    this.thumbnail = loadImage(thumbnailUrl);
  }
  
  public String getThumbnailUrl() {
    return thumbnailUrl;
  }
  
  public PImage getThumbnail() {
    return thumbnail;
  }
  
  public String getLinkUrl() {
    return linkUrl;
  }
}


class Instagram {

  String API_URL = "https://api.instagram.com/v1/";
  String clientID;
  
  public Instagram(String clientID) {
    this.clientID = clientID;
  }

  public ArrayList<InstagramPhoto> getPhotosNearby(String lat, String lng) {
    println("Instagram.getPhotosNearby " + lat + " " + lng);
    String request = API_URL + "media/search?lat=" + lat + "&lng=" + lng + "&distance=5000&client_id=" + clientID;
    return makeRequest(request);
  }
  
  public ArrayList<InstagramPhoto> getPopularPhotos() {
    println("Instagram.getPopularPhotos");    
    String request = API_URL + "media/popular?client_id=" + clientID;
    return makeRequest(request);    
  }
  
  public ArrayList<InstagramPhoto> getPhotosWithTag(String tag) {
    println("Instagram.getPhotosWithTag " + tag);    
    String request = API_URL + "tags/" + tag + "/media/recent?client_id=" + clientID;
    return makeRequest(request);    
  }
  
  private ArrayList<InstagramPhoto> makeRequest(String request) {
    ArrayList<InstagramPhoto> photos = new ArrayList<InstagramPhoto>();
    try {
      String[] resultArray = loadStrings( request );
      if (resultArray == null) {
        println ("No photos found!");
        return photos;
      }
      String result = join(resultArray , "");
    
    
      JSONObject instagramData = new JSONObject(join(loadStrings(request), ""));
      JSONArray data = instagramData.getJSONArray("data");
      for(int i=0; i<data.length(); i++) {
        JSONObject picture = data.getJSONObject(i);  
        String thumbnailUrl = picture.getJSONObject("images").getJSONObject("thumbnail").getString("url");
        String linkUrl = picture.getString("link");
        println("Loading... " + thumbnailUrl);
        photos.add(new InstagramPhoto(thumbnailUrl, linkUrl));        
      }
    }
    catch (JSONException e) {
      println ("No photos found!");
    }
    catch (Exception e) {
      println ("No photos found!");
    }
    return photos;
  }    

}

